@@ -134,6 +134,14 @@ def access_list(owner, urn_type, json_output):
         table_data = []
         table_data.append(("URN:", resource.get("urn")))
         table_data.append(("Owner:", resource.get("owner")))
+        table_data.append(
+            (
+                "Access:",
+                click.style("Private", fg="red")
+                if resource.get("private", False)
+                else "Public",
+            )
+        )
         table_data.append(
             (
                 "Access level(s):",
