@@ -13,12 +13,14 @@
 # limitations under the License.
 
 import json
+import logging
 import os
 
 import click
 
-from platformio.cache import cleanup_content_cache
 from platformio.commands.boards import print_boards
+from platformio.exception import UserSideException
+from platformio.package.exception import UnknownPackageError
 from platformio.package.manager.platform import PlatformPackageManager
 from platformio.package.meta import PackageItem, PackageSpec
 from platformio.package.version import get_original_version
@@ -26,7 +28,7 @@ from platformio.platform.exception import UnknownPlatform
 from platformio.platform.factory import PlatformFactory
 
 
-@click.group(short_help="Platform manager")
+@click.group(short_help="Platform manager", hidden=True)
 def cli():
     pass
 
@@ -61,7 +63,7 @@ def platform_frameworks(query, json_output):
     regclient = PlatformPackageManager().get_registry_client_instance()
     frameworks = []
     for framework in regclient.fetch_json_data(
-        "get", "/v2/frameworks", cache_valid="1d"
+        "get", "/v2/frameworks", x_cache_valid="1d"
     ):
         if query == "all":
             query = ""
@@ -178,7 +180,7 @@ def platform_show(platform, json_output):  # pylint: disable=too-many-branches
     is_flag=True,
     help="Reinstall/redownload dev/platform and its packages if exist",
 )
-def platform_install(  # pylint: disable=too-many-arguments
+def platform_install(  # pylint: disable=too-many-arguments,too-many-locals
     platforms,
     with_package,
     without_package,
@@ -187,37 +189,50 @@ def platform_install(  # pylint: disable=too-many-arguments
     silent,
     force,
 ):
-    return _platform_install(
-        platforms,
-        with_package,
-        without_package,
-        skip_default_package,
-        with_all_packages,
-        silent,
-        force,
-    )
+    def _find_pkg_names(p, candidates):
+        result = []
+        for candidate in candidates:
+            found = False
+            # lookup by package types
+            for _name, _opts in p.packages.items():
+                if _opts.get("type") == candidate:
+                    result.append(_name)
+                    found = True
+            if (
+                p.frameworks
+                and candidate.startswith("framework-")
+                and candidate[10:] in p.frameworks
+            ):
+                result.append(p.frameworks[candidate[10:]]["package"])
+                found = True
+            if not found:
+                result.append(candidate)
+        return result
 
-
-def _platform_install(  # pylint: disable=too-many-arguments
-    platforms,
-    with_package=None,
-    without_package=None,
-    skip_default_package=False,
-    with_all_packages=False,
-    silent=False,
-    force=False,
-):
     pm = PlatformPackageManager()
+    pm.set_log_level(logging.WARN if silent else logging.DEBUG)
     for platform in platforms:
-        pkg = pm.install(
-            spec=platform,
-            with_packages=with_package or [],
-            without_packages=without_package or [],
-            skip_default_package=skip_default_package,
-            with_all_packages=with_all_packages,
-            silent=silent,
-            force=force,
-        )
+        if with_package or without_package or with_all_packages:
+            pkg = pm.install(platform, skip_dependencies=True)
+            p = PlatformFactory.new(pkg)
+            if with_all_packages:
+                with_package = list(p.packages)
+            with_package = set(_find_pkg_names(p, with_package or []))
+            without_package = set(_find_pkg_names(p, without_package or []))
+            upkgs = with_package | without_package
+            ppkgs = set(p.packages)
+            if not upkgs.issubset(ppkgs):
+                raise UnknownPackageError(", ".join(upkgs - ppkgs))
+            for name, options in p.packages.items():
+                if name in without_package:
+                    continue
+                if name in with_package or not (
+                    skip_default_package or options.get("optional", False)
+                ):
+                    p.pm.install(p.get_package_spec(name), force=force)
+        else:
+            pkg = pm.install(platform, skip_dependencies=skip_default_package)
+
         if pkg and not silent:
             click.secho(
                 "The platform '%s' has been successfully installed!\n"
@@ -231,6 +246,7 @@ def _platform_install(  # pylint: disable=too-many-arguments
 @click.argument("platforms", nargs=-1, required=True, metavar="[PLATFORM...]")
 def platform_uninstall(platforms):
     pm = PlatformPackageManager()
+    pm.set_log_level(logging.DEBUG)
     for platform in platforms:
         if pm.uninstall(platform):
             click.secho(
@@ -256,9 +272,15 @@ def platform_uninstall(platforms):
 @click.option("-s", "--silent", is_flag=True, help="Suppress progress reporting")
 @click.option("--json-output", is_flag=True)
 def platform_update(  # pylint: disable=too-many-locals, too-many-arguments
-    platforms, only_packages, only_check, dry_run, silent, json_output
+    platforms, only_check, dry_run, silent, json_output, **_
 ):
+    if only_check and not json_output:
+        raise UserSideException(
+            "This command is deprecated, please use `pio pkg outdated` instead"
+        )
+
     pm = PlatformPackageManager()
+    pm.set_log_level(logging.WARN if silent else logging.DEBUG)
     platforms = platforms or pm.get_installed()
     only_check = dry_run or only_check
 
@@ -290,9 +312,6 @@ def platform_update(  # pylint: disable=too-many-locals, too-many-arguments
             result.append(data)
         return click.echo(json.dumps(result))
 
-    # cleanup cached board and platform lists
-    cleanup_content_cache("http")
-
     for platform in platforms:
         click.echo(
             "Platform %s"
@@ -304,9 +323,7 @@ def platform_update(  # pylint: disable=too-many-locals, too-many-arguments
             )
         )
         click.echo("--------")
-        pm.update(
-            platform, only_packages=only_packages, only_check=only_check, silent=silent
-        )
+        pm.update(platform)
         click.echo()
 
     return True
@@ -317,15 +334,6 @@ def platform_update(  # pylint: disable=too-many-locals, too-many-arguments
 #
 
 
-def init_platform(name, skip_default_package=True, auto_install=True):
-    try:
-        return PlatformFactory.new(name)
-    except UnknownPlatform:
-        if auto_install:
-            _platform_install([name], skip_default_package=skip_default_package)
-        return PlatformFactory.new(name)
-
-
 def _print_platforms(platforms):
     for platform in platforms:
         click.echo(
@@ -354,7 +362,7 @@ def _print_platforms(platforms):
 
 def _get_registry_platforms():
     regclient = PlatformPackageManager().get_registry_client_instance()
-    return regclient.fetch_json_data("get", "/v2/platforms", cache_valid="1d")
+    return regclient.fetch_json_data("get", "/v2/platforms", x_cache_valid="1d")
 
 
 def _get_platform_data(*args, **kwargs):
