@@ -48,7 +48,7 @@ class LockFile(object):
     def __init__(self, path, timeout=LOCKFILE_TIMEOUT, delay=LOCKFILE_DELAY):
         self.timeout = timeout
         self.delay = delay
-        self._lock_path = os.path.realpath(path) + ".lock"
+        self._lock_path = os.path.abspath(path) + ".lock"
         self._fp = None
 
     def _lock(self):
@@ -69,8 +69,11 @@ class LockFile(object):
             if LOCKFILE_CURRENT_INTERFACE == LOCKFILE_INTERFACE_FCNTL:
                 fcntl.flock(self._fp.fileno(), fcntl.LOCK_EX | fcntl.LOCK_NB)
             elif LOCKFILE_CURRENT_INTERFACE == LOCKFILE_INTERFACE_MSVCRT:
-                msvcrt.locking(self._fp.fileno(), msvcrt.LK_NBLCK, 1)
-        except IOError:
+                msvcrt.locking(  # pylint: disable=used-before-assignment
+                    self._fp.fileno(), msvcrt.LK_NBLCK, 1
+                )
+        except (BlockingIOError, IOError):
+            self._fp.close()
             self._fp = None
             raise LockFileExists
         return True
