@@ -17,18 +17,15 @@ import os
 import re
 import tarfile
 from binascii import crc32
+from urllib.parse import urlparse
 
 import semantic_version
 
+from platformio import fs
 from platformio.compat import get_object_members, hashlib_encode_data, string_types
 from platformio.package.manifest.parser import ManifestFileType
 from platformio.package.version import cast_version_to_semver
 
-try:
-    from urllib.parse import urlparse
-except ImportError:
-    from urlparse import urlparse
-
 
 class PackageType(object):
     LIBRARY = "library"
@@ -67,6 +64,10 @@ class PackageType(object):
 
 
 class PackageOutdatedResult(object):
+    UPDATE_INCREMENT_MAJOR = "major"
+    UPDATE_INCREMENT_MINOR = "minor"
+    UPDATE_INCREMENT_PATCH = "patch"
+
     def __init__(self, current, latest=None, wanted=None, detached=False):
         self.current = current
         self.latest = latest
@@ -91,7 +92,25 @@ class PackageOutdatedResult(object):
             and not isinstance(value, semantic_version.Version)
         ):
             value = cast_version_to_semver(str(value))
-        return super(PackageOutdatedResult, self).__setattr__(name, value)
+        return super().__setattr__(name, value)
+
+    @property
+    def update_increment_type(self):
+        if not self.current or not self.latest:
+            return None
+        patch_conds = [
+            self.current.major == self.latest.major,
+            self.current.minor == self.latest.minor,
+        ]
+        if all(patch_conds):
+            return self.UPDATE_INCREMENT_PATCH
+        minor_conds = [
+            self.current.major == self.latest.major,
+            self.current.major > 0,
+        ]
+        if all(minor_conds):
+            return self.UPDATE_INCREMENT_MINOR
+        return self.UPDATE_INCREMENT_MAJOR
 
     def is_outdated(self, allow_incompatible=False):
         if self.detached or not self.latest or self.current == self.latest:
@@ -105,19 +124,19 @@ class PackageOutdatedResult(object):
 
 class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=redefined-builtin,too-many-arguments
-        self, raw=None, owner=None, id=None, name=None, requirements=None, url=None
+        self, raw=None, owner=None, id=None, name=None, requirements=None, uri=None
     ):
         self._requirements = None
         self.owner = owner
         self.id = id
         self.name = name
-        self.url = url
+        self.uri = uri
         self.raw = raw
         if requirements:
             try:
                 self.requirements = requirements
             except ValueError as exc:
-                if not self.name or self.url or self.raw:
+                if not self.name or self.uri or self.raw:
                     raise exc
                 self.raw = "%s=%s" % (self.name, requirements)
         self._name_is_custom = False
@@ -130,7 +149,7 @@ class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
                 self.id == other.id,
                 self.name == other.name,
                 self.requirements == other.requirements,
-                self.url == other.url,
+                self.uri == other.uri,
             ]
         )
 
@@ -138,19 +157,23 @@ class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
         return crc32(
             hashlib_encode_data(
                 "%s-%s-%s-%s-%s"
-                % (self.owner, self.id, self.name, self.requirements, self.url)
+                % (self.owner, self.id, self.name, self.requirements, self.uri)
             )
         )
 
     def __repr__(self):
         return (
             "PackageSpec <owner={owner} id={id} name={name} "
-            "requirements={requirements} url={url}>".format(**self.as_dict())
+            "requirements={requirements} uri={uri}>".format(**self.as_dict())
         )
 
     @property
     def external(self):
-        return bool(self.url)
+        return bool(self.uri)
+
+    @property
+    def symlink(self):
+        return self.uri and self.uri.startswith("symlink://")
 
     @property
     def requirements(self):
@@ -169,8 +192,8 @@ class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
 
     def humanize(self):
         result = ""
-        if self.url:
-            result = self.url
+        if self.uri:
+            result = self.uri
         elif self.name:
             if self.owner:
                 result = self.owner + "/"
@@ -190,12 +213,12 @@ class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
             id=self.id,
             name=self.name,
             requirements=str(self.requirements) if self.requirements else None,
-            url=self.url,
+            uri=self.uri,
         )
 
     def as_dependency(self):
-        if self.url:
-            return self.raw or self.url
+        if self.uri:
+            return self.raw or self.uri
         result = ""
         if self.name:
             result = "%s/%s" % (self.owner, self.name) if self.owner else self.name
@@ -219,30 +242,32 @@ class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
             self._parse_custom_name,
             self._parse_id,
             self._parse_owner,
-            self._parse_url,
+            self._parse_uri,
         )
         for parser in parsers:
             if raw is None:
                 break
             raw = parser(raw)
 
-        # if name is not custom, parse it from URL
-        if not self.name and self.url:
-            self.name = self._parse_name_from_url(self.url)
+        # if name is not custom, parse it from URI
+        if not self.name and self.uri:
+            self.name = self._parse_name_from_uri(self.uri)
         elif raw:
             # the leftover is a package name
             self.name = raw
 
     @staticmethod
     def _parse_local_file(raw):
-        if raw.startswith("file://") or not any(c in raw for c in ("/", "\\")):
+        if raw.startswith(("file://", "symlink://")) or not any(
+            c in raw for c in ("/", "\\")
+        ):
             return raw
         if os.path.exists(raw):
             return "file://%s" % raw
         return raw
 
     def _parse_requirements(self, raw):
-        if "@" not in raw or raw.startswith("file://"):
+        if "@" not in raw or raw.startswith(("file://", "symlink://")):
             return raw
         tokens = raw.rsplit("@", 1)
         if any(s in tokens[1] for s in (":", "/")):
@@ -276,14 +301,18 @@ class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
         self.name = tokens[1].strip()
         return None
 
-    def _parse_url(self, raw):
+    def _parse_uri(self, raw):
         if not any(s in raw for s in ("@", ":", "/")):
             return raw
-        self.url = raw.strip()
-        parts = urlparse(self.url)
+        self.uri = raw.strip()
+        parts = urlparse(self.uri)
 
-        # if local file or valid URL with scheme vcs+protocol://
-        if parts.scheme == "file" or "+" in parts.scheme or self.url.startswith("git+"):
+        # if local file or valid URI with scheme vcs+protocol://
+        if (
+            parts.scheme in ("file", "symlink://")
+            or "+" in parts.scheme
+            or self.uri.startswith("git+")
+        ):
             return None
 
         # parse VCS
@@ -301,29 +330,29 @@ class PackageSpec(object):  # pylint: disable=too-many-instance-attributes
             in ("mbed.com", "os.mbed.com", "developer.mbed.org")
         ]
         if any(git_conditions):
-            self.url = "git+" + self.url
+            self.uri = "git+" + self.uri
         elif any(hg_conditions):
-            self.url = "hg+" + self.url
+            self.uri = "hg+" + self.uri
 
         return None
 
     @staticmethod
-    def _parse_name_from_url(url):
-        if url.endswith("/"):
-            url = url[:-1]
+    def _parse_name_from_uri(uri):
+        if uri.endswith("/"):
+            uri = uri[:-1]
         stop_chars = ["#", "?"]
-        if url.startswith("file://"):
+        if uri.startswith(("file://", "symlink://")):
             stop_chars.append("@")  # detached path
         for c in stop_chars:
-            if c in url:
-                url = url[: url.index(c)]
+            if c in uri:
+                uri = uri[: uri.index(c)]
 
         # parse real repository name from Github
-        parts = urlparse(url)
+        parts = urlparse(uri)
         if parts.netloc == "github.com" and parts.path.count("/") > 2:
             return parts.path.split("/")[2]
 
-        name = os.path.basename(url)
+        name = os.path.basename(uri)
         if "." in name:
             return name.split(".", 1)[0].strip()
         return name
@@ -387,11 +416,14 @@ class PackageMetaData(object):
 
     @staticmethod
     def load(path):
-        with open(path, encoding="utf8") as fp:
-            data = json.load(fp)
-            if data["spec"]:
-                data["spec"] = PackageSpec(**data["spec"])
-            return PackageMetaData(**data)
+        data = fs.load_json(path)
+        if data["spec"]:
+            # legacy support for Core<5.3 packages
+            if "url" in data["spec"]:
+                data["spec"]["uri"] = data["spec"]["url"]
+                del data["spec"]["url"]
+            data["spec"] = PackageSpec(**data["spec"])
+        return PackageMetaData(**data)
 
 
 class PackageItem(object):
@@ -410,9 +442,13 @@ class PackageItem(object):
         )
 
     def __eq__(self, other):
-        if not self.path or not other.path:
-            return self.path == other.path
-        return os.path.realpath(self.path) == os.path.realpath(other.path)
+        conds = [
+            os.path.realpath(self.path) == os.path.realpath(other.path)
+            if self.path and other.path
+            else self.path == other.path,
+            self.metadata == other.metadata,
+        ]
+        return all(conds)
 
     def __hash__(self):
         return hash(os.path.realpath(self.path))
