@@ -60,7 +60,7 @@ class ConfigOption(object):  # pylint: disable=too-many-instance-attributes
             type="string",
             multiple=self.multiple,
             sysenvvar=self.sysenvvar,
-            default=self.default,
+            default=self.default() if callable(self.default) else self.default,
         )
         if isinstance(self.type, click.ParamType):
             result["type"] = self.type.name
@@ -114,17 +114,16 @@ def validate_dir(path):
         path = fs.expanduser(path)
     if "$" in path:
         path = expand_dir_templates(path)
-    return os.path.realpath(path)
+    return fs.normalize_path(path)
 
 
-def validate_core_dir(path):
-    default_dir = ProjectOptions["platformio.core_dir"].default
-    win_core_dir = None
-    if IS_WINDOWS and path == default_dir:
+def get_default_core_dir():
+    path = os.path.join(fs.expanduser("~"), ".platformio")
+    if IS_WINDOWS:
         win_core_dir = os.path.splitdrive(path)[0] + "\\.platformio"
         if os.path.isdir(win_core_dir):
-            path = win_core_dir
-    return validate_dir(path)
+            return win_core_dir
+    return path
 
 
 ProjectOptions = OrderedDict(
@@ -169,8 +168,8 @@ ProjectOptions = OrderedDict(
                 ),
                 oldnames=["home_dir"],
                 sysenvvar="PLATFORMIO_CORE_DIR",
-                default=os.path.join(fs.expanduser("~"), ".platformio"),
-                validate=validate_core_dir,
+                default=get_default_core_dir,
+                validate=validate_dir,
             ),
             ConfigPlatformioOption(
                 group="directory",
@@ -404,7 +403,7 @@ ProjectOptions = OrderedDict(
                 group="build",
                 name="build_type",
                 description="Project build configuration",
-                type=click.Choice(["release", "debug"]),
+                type=click.Choice(["release", "test", "debug"]),
                 default="release",
             ),
             ConfigEnvOption(
@@ -420,13 +419,14 @@ ProjectOptions = OrderedDict(
             ),
             ConfigEnvOption(
                 group="build",
-                name="src_build_flags",
+                name="build_src_flags",
+                oldnames=["src_build_flags"],
                 description=(
                     "The same as `build_flags` but configures flags the only for "
-                    "project source files (`src` folder)"
+                    "project source files in the `src` folder"
                 ),
                 multiple=True,
-                sysenvvar="PLATFORMIO_SRC_BUILD_FLAGS",
+                sysenvvar="PLATFORMIO_BUILD_SRC_FLAGS",
                 buildenvvar="SRC_BUILD_FLAGS",
             ),
             ConfigEnvOption(
@@ -439,13 +439,14 @@ ProjectOptions = OrderedDict(
             ),
             ConfigEnvOption(
                 group="build",
-                name="src_filter",
+                name="build_src_filter",
+                oldnames=["src_filter"],
                 description=(
-                    "Control which source files should be included/excluded from a "
-                    "build process"
+                    "Control which source files from the `src` folder should "
+                    "be included/excluded from a build process"
                 ),
                 multiple=True,
-                sysenvvar="PLATFORMIO_SRC_FILTER",
+                sysenvvar="PLATFORMIO_BUILD_SRC_FILTER",
                 buildenvvar="SRC_FILTER",
                 default="+<*> -<.git/> -<.svn/>",
             ),
@@ -647,6 +648,13 @@ ProjectOptions = OrderedDict(
                 default=False,
             ),
             # Test
+            ConfigEnvOption(
+                group="test",
+                name="test_framework",
+                description="A unit testing framework",
+                type=click.Choice(["doctest", "googletest", "unity", "custom"]),
+                default="unity",
+            ),
             ConfigEnvOption(
                 group="test",
                 name="test_filter",
@@ -669,19 +677,25 @@ ProjectOptions = OrderedDict(
                 name="test_speed",
                 description="A connection speed (baud rate) to communicate with a target device",
                 type=click.INT,
+                default=115200,
             ),
             ConfigEnvOption(
                 group="test",
-                name="test_transport",
-                description="A transport to communicate with a target device",
-            ),
-            ConfigEnvOption(
-                group="test",
-                name="test_build_project_src",
-                description="Build project source code in a pair with test code",
+                name="test_build_src",
+                oldnames=["test_build_project_src"],
+                description="Build main source code in pair with a test code",
                 type=click.BOOL,
                 default=False,
             ),
+            ConfigEnvOption(
+                group="test",
+                name="test_testing_command",
+                multiple=True,
+                description=(
+                    "A custom testing command that runs test cases "
+                    "and returns results to the standard output"
+                ),
+            ),
             # Debug
             ConfigEnvOption(
                 group="debug",
